@@ -20,7 +20,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/** \file mksum.c Generate file signatures.
+/** \file mksum.c
+ * Generate file signatures.
  *
  * Generating checksums is pretty easy, since we can always just process
  * whatever data is available. When a whole block has arrived, or we've reached
@@ -31,18 +32,15 @@
  * the moment, though, because tails are only used if necessary. */
 
 #include "config.h"
-
-#include <stdlib.h>
-#include <stdio.h>
 #include <assert.h>
-
+#include <stdlib.h>
 #include "librsync.h"
-#include "stream.h"
-#include "util.h"
-#include "sumset.h"
 #include "job.h"
+#include "sumset.h"
+#include "stream.h"
 #include "netint.h"
 #include "trace.h"
+#include "util.h"
 
 /* Possible state functions for signature generation. */
 static rs_result rs_sig_s_header(rs_job_t *);
@@ -77,7 +75,7 @@ static rs_result rs_sig_do_block(rs_job_t *job, const void *block, size_t len)
     rs_weak_sum_t weak_sum;
     rs_strong_sum_t strong_sum;
 
-    weak_sum = rs_calc_weak_sum(block, len);
+    weak_sum = rs_signature_calc_weak_sum(sig, block, len);
     rs_signature_calc_strong_sum(sig, block, len, &strong_sum);
     rs_squirt_n4(job, weak_sum);
     rs_tube_write(job, strong_sum, sig->strong_sum_len);
@@ -114,7 +112,7 @@ static rs_result rs_sig_s_generate(rs_job_t *job)
     return rs_sig_do_block(job, block, len);
 }
 
-rs_job_t *rs_sig_begin(size_t new_block_len, size_t strong_sum_len,
+rs_job_t *rs_sig_begin(size_t block_len, size_t strong_len,
                        rs_magic_number sig_magic)
 {
     rs_job_t *job;
@@ -123,7 +121,7 @@ rs_job_t *rs_sig_begin(size_t new_block_len, size_t strong_sum_len,
     job->signature = rs_alloc_struct(rs_signature_t);
     job->job_owns_sig = 1;
     job->sig_magic = sig_magic;
-    job->sig_block_len = new_block_len;
-    job->sig_strong_len = strong_sum_len;
+    job->sig_block_len = block_len;
+    job->sig_strong_len = strong_len;
     return job;
 }
